# coding: utf-8

"""
    RTU MIREA VUC

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.2.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Optional
from pydantic import BaseModel
from typing import Dict, Any
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class WorkbookFile(BaseModel):
    """
    WorkbookFile
    """
    course: Optional[Any]
    workbook_path: Optional[Any]
    worksheet_settings_path: Optional[Any]
    worksheet_settings: Optional[Any]
    __properties: ClassVar[List[str]] = ["course", "workbook_path", "worksheet_settings_path", "worksheet_settings"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WorkbookFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if course (nullable) is None
        # and model_fields_set contains the field
        if self.course is None and "course" in self.model_fields_set:
            _dict['course'] = None

        # set to None if workbook_path (nullable) is None
        # and model_fields_set contains the field
        if self.workbook_path is None and "workbook_path" in self.model_fields_set:
            _dict['workbook_path'] = None

        # set to None if worksheet_settings_path (nullable) is None
        # and model_fields_set contains the field
        if self.worksheet_settings_path is None and "worksheet_settings_path" in self.model_fields_set:
            _dict['worksheet_settings_path'] = None

        # set to None if worksheet_settings (nullable) is None
        # and model_fields_set contains the field
        if self.worksheet_settings is None and "worksheet_settings" in self.model_fields_set:
            _dict['worksheet_settings'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        """Create an instance of WorkbookFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "course": obj.get("course"),
            "workbook_path": obj.get("workbook_path"),
            "worksheet_settings_path": obj.get("worksheet_settings_path"),
        })
        return _obj


